@@ -522,6 +522,9 @@ modelica_real* real_array_element_addr1(const real_array_t * source,int ndims,in
 
 modelica_real* real_array_element_addr2(const real_array_t * source,int ndims,int dim1,int dim2)
 {
+    if (dim1 < 1 || dim1 > source->dim_size[0] || dim2 < 1 || dim2 > source->dim_size[1]) {
+      throwStreamPrint(NULL, "real_array_element_addr2: array has dimensions [%ld,%ld], got subscripts [%d,%d]", source->dim_size[1], source->dim_size[2], dim1, dim2);
+    }
     return real_ptrget(source, ((dim1 - 1) * source->dim_size[1]) + (dim2 - 1));
 }
 
@@ -709,28 +712,28 @@ real_array_t add_alloc_real_array(const real_array_t a, const real_array_t b)
     return dest;
 }
 
-real_array_t add_alloc_scalar_real_array(modelica_real sc, const real_array_t *arr)
+real_array_t add_alloc_real_array_scalar(const real_array_t arr, const modelica_real sc)
 {
   size_t nr_of_elements, i;
   real_array_t dest;
-  clone_real_array_spec(arr, &dest);
+  clone_real_array_spec(&arr, &dest);
   alloc_real_array_data(&dest);
-  nr_of_elements = base_array_nr_of_elements(*arr);
+  nr_of_elements = base_array_nr_of_elements(arr);
   for(i=0; i < nr_of_elements; ++i) {
-    real_set(&dest, i, sc + real_get(*arr, i));
+    real_set(&dest, i, sc + real_get(arr, i));
   }
   return dest;
 }
 
-real_array_t sub_alloc_scalar_real_array(modelica_real sc, const real_array_t *arr)
+real_array_t sub_alloc_scalar_real_array(modelica_real sc, const real_array_t arr)
 {
   size_t nr_of_elements, i;
   real_array_t dest;
-  clone_real_array_spec(arr, &dest);
+  clone_real_array_spec(&arr, &dest);
   alloc_real_array_data(&dest);
-  nr_of_elements = base_array_nr_of_elements(*arr);
+  nr_of_elements = base_array_nr_of_elements(arr);
   for(i=0; i < nr_of_elements; ++i) {
-    real_set(&dest, i, sc - real_get(*arr, i));
+    real_set(&dest, i, sc - real_get(arr, i));
   }
   return dest;
 }
@@ -806,6 +809,7 @@ void mul_scalar_real_array(modelica_real a,const real_array_t * b,real_array_t*
     }
 }
 
+// TODO: remove me.
 real_array_t mul_alloc_scalar_real_array(modelica_real a,const real_array_t b)
 {
     real_array_t dest;
@@ -826,7 +830,7 @@ void mul_real_array_scalar(const real_array_t * a,modelica_real b,real_array_t*
     }
 }
 
-real_array_t mul_alloc_real_array_scalar(const real_array_t a,modelica_real b)
+real_array_t mul_alloc_real_array_scalar(const real_array_t a, const modelica_real b)
 {
     real_array_t dest;
     clone_real_array_spec(&a,&dest);
@@ -976,7 +980,7 @@ void div_real_array_scalar(const real_array_t * a,modelica_real b,real_array_t*
     }
 }
 
-real_array_t div_alloc_real_array_scalar(const real_array_t a,modelica_real b)
+real_array_t div_alloc_real_array_scalar(const real_array_t a, const modelica_real b)
 {
     real_array_t dest;
     clone_real_array_spec(&a,&dest);
@@ -1059,7 +1063,7 @@ void pow_real_array_scalar(const real_array_t *a, modelica_real b, real_array_t*
   }
 }
 
-real_array_t pow_alloc_real_array_scalar(const real_array_t a, modelica_real b)
+real_array_t pow_alloc_real_array_scalar(const real_array_t a, const modelica_real b)
 {
   real_array_t dest;
   clone_real_array_spec(&a, &dest);
