@@ -60,7 +60,7 @@ class PlotWindow : public QMainWindow
 {
   Q_OBJECT
 public:
-  enum PlotType {PLOT, PLOTALL, PLOTPARAMETRIC};
+  enum PlotType {PLOT, PLOTALL, PLOTPARAMETRIC, PLOTINTERACTIVE, PLOTARRAY, PLOTARRAYPARAMETRIC};
 private:
   Plot *mpPlot;
   QCheckBox *mpLogXCheckBox;
@@ -68,10 +68,12 @@ private:
   QToolButton *mpGridButton;
   QToolButton *mpDetailedGridButton;
   QToolButton *mpNoGridButton;
-  QToolButton *mpZoomButton;
-  QToolButton *mpPanButton;
   QToolButton *mpAutoScaleButton;
   QToolButton *mpSetupButton;
+  QToolButton *mpStartSimulationToolButton;
+  QToolButton *mpPauseSimulationToolButton;
+  QLabel *mpSimulationSpeedLabel;
+  QComboBox *mpSimulationSpeedComboBox;
   QTextStream *mpTextStream;
   QFile mFile;
   QStringList mVariablesList;
@@ -86,8 +88,17 @@ private:
   QString mYRangeMax;
   double mCurveWidth;
   int mCurveStyle;
+  QFont mLegendFont;
+  double mTime;
+  bool mIsInteractiveSimulation;
+  QString mInteractiveTreeItemOwner;
+  int mInteractivePort;
+  QwtSeriesData<QPointF>* mpInteractiveData;
+  QString mInteractiveModelName;
+  QMdiSubWindow *mpSubWindow;
 public:
-  PlotWindow(QStringList arguments = QStringList(), QWidget *parent = 0);
+  PlotWindow(QStringList arguments = QStringList(), QWidget *parent = 0, bool isInteractiveSimulation = false);
+
   ~PlotWindow();
 
   void setUpWidget();
@@ -96,15 +107,30 @@ public:
   void setPlotType(PlotType type);
   PlotType getPlotType();
   void initializeFile(QString file);
+  void getStartStopTime(double &start, double &stop);
   void setupToolbar();
   void plot(PlotCurve *pPlotCurve = 0);
   void plotParametric(PlotCurve *pPlotCurve = 0);
+  void plotArray(double time, PlotCurve *pPlotCurve = 0);
+  void plotArrayParametric(double time, PlotCurve *pPlotCurve = 0);
+  QPair<QVector<double>*, QVector<double>*> plotInteractive(PlotCurve *pPlotCurve = 0);
+  void setInteractiveOwner(const QString &interactiveTreeItemOwner);
+  void setInteractivePort(const int port);
+  void setInteractivePlotData(QwtSeriesData<QPointF>* pInteractiveData);
+  void setSubWindow(QMdiSubWindow *pSubWindow) {mpSubWindow = pSubWindow;}
+  QMdiSubWindow* getSubWindow() {return mpSubWindow;}
+  void setInteractiveModelName(const QString &modelName);
+  QString getInteractiveOwner() {return mInteractiveTreeItemOwner;}
+  int getInteractivePort() {return mInteractivePort;}
   void setTitle(QString title);
   void setGrid(QString grid);
   QString getGrid();
   QCheckBox* getLogXCheckBox();
   QCheckBox* getLogYCheckBox();
   QToolButton* getAutoScaleButton() {return mpAutoScaleButton;}
+  QToolButton* getStartSimulationButton() {return mpStartSimulationToolButton;}
+  QToolButton* getPauseSimulationButton() {return mpPauseSimulationToolButton;}
+  QComboBox* getSimulationSpeedBox() {return mpSimulationSpeedComboBox;}
   void setXLabel(QString label);
   void setYLabel(QString label);
   void setUnit(QString unit) {mUnit = unit;}
@@ -123,15 +149,21 @@ public:
   double getCurveWidth();
   void setCurveStyle(int style);
   int getCurveStyle();
+  void setLegendFont(QFont font);
+  QFont getLegendFont();
   void setLegendPosition(QString position);
   QString getLegendPosition();
   void setFooter(QString footer);
   QString getFooter();
   void checkForErrors(QStringList variables, QStringList variablesPlotted);
   Plot* getPlot();
-  QToolButton* getPanButton();
   void receiveMessage(QStringList arguments);
   void closeEvent(QCloseEvent *event);
+  void setTime(double time){mTime = time;}
+  double getTime() {return mTime;}
+  void updateTimeText(QString unit);
+  void updateCurves();
+  void updateYAxis(QPair<double, double> minMaxValues);
 signals:
   void closingDown();
 public slots:
@@ -223,16 +255,43 @@ private:
   QWidget *mpTitlesTab;
   QLabel *mpPlotTitleLabel;
   QLineEdit *mpPlotTitleTextBox;
+  QLabel *mpTitleFontSizeLabel;
+  QDoubleSpinBox *mpTitleFontSizeSpinBox;
   QLabel *mpVerticalAxisLabel;
   QLineEdit *mpVerticalAxisTextBox;
+  QLabel *mpVerticalAxisTitleFontSizeLabel;
+  QDoubleSpinBox *mpVerticalAxisTitleFontSizeSpinBox;
+  QLabel *mpVerticalAxisNumbersFontSizeLabel;
+  QDoubleSpinBox *mpVerticalAxisNumbersFontSizeSpinBox;
   QLabel *mpHorizontalAxisLabel;
   QLineEdit *mpHorizontalAxisTextBox;
+  QLabel *mpHorizontalAxisTitleFontSizeLabel;
+  QDoubleSpinBox *mpHorizontalAxisTitleFontSizeSpinBox;
+  QLabel *mpHorizontalAxisNumbersFontSizeLabel;
+  QDoubleSpinBox *mpHorizontalAxisNumbersFontSizeSpinBox;
   QLabel *mpPlotFooterLabel;
   QLineEdit *mpPlotFooterTextBox;
+  QLabel *mpFooterFontSizeLabel;
+  QDoubleSpinBox *mpFooterFontSizeSpinBox;
   /* legend tab */
   QWidget *mpLegendTab;
   QLabel *mpLegendPositionLabel;
   QComboBox *mpLegendPositionComboBox;
+  QLabel *mpLegendFontSizeLabel;
+  QDoubleSpinBox *mpLegendFontSizeSpinBox;
+  /* range tab */
+  QWidget *mpRangeTab;
+  QCheckBox *mpAutoScaleCheckbox;
+  QGroupBox *mpXAxisGroupBox;
+  QLabel *mpXMinimumLabel;
+  QLineEdit *mpXMinimumTextBox;
+  QLabel *mpXMaximumLabel;
+  QLineEdit *mpXMaximumTextBox;
+  QGroupBox *mpYAxisGroupBox;
+  QLabel *mpYMinimumLabel;
+  QLineEdit *mpYMinimumTextBox;
+  QLabel *mpYMaximumLabel;
+  QLineEdit *mpYMaximumTextBox;
   /* buttons */
   QPushButton *mpOkButton;
   QPushButton *mpApplyButton;
@@ -244,6 +303,7 @@ public:
   void setupPlotCurve(VariablePageWidget *pVariablePageWidget);
 public slots:
   void variableSelected(QListWidgetItem *current, QListWidgetItem *previous);
+  void autoScaleChecked(bool checked);
   void saveSetup();
   void applySetup();
 };
