@@ -21,7 +21,7 @@
  * GNU version 3 is obtained from: http://www.gnu.org/copyleft/gpl.html.
  *
  * This program is distributed WITHOUT ANY WARRANTY; without
- * even the implied warranty of  MERCHANTABILITY or FITNESS
+ * even the implied warranty of MERCHANTABILITY or FITNESS
  * FOR A PARTICULAR PURPOSE, EXCEPT AS EXPRESSLY SET FORTH
  * IN THE BY RECIPIENT SELECTED SUBSIDIARY LICENSE CONDITIONS OF OSMC-PL.
  *
@@ -61,20 +61,31 @@ oms::Flags::~Flags()
 
 void oms::Flags::setDefaults()
 {
-  ignoreInitialUnknowns = false;
-  suppressPath = false;
-  progressBar = false;
-  inputDerivatives = false;
+  addParametersToCSV = false;
   defaultModeIsCS = false;
-  wallTime = false;
+  deleteTempFiles = true;
+  emitEvents = true;
+  exportParametersInline = true;
+  ignoreInitialUnknowns = false;
+  inputExtrapolation = false;
   intervals = 100;
+  masterAlgorithm = oms_solver_wc_ma;
+  maxEventIteration = 100;
+  maxLoopIteration = 10;
+  numProcs = 1;
+  progressBar = false;
+  realTime = false;
+  resultFile = "<default>";
+  skipCSVHeader = false;
+  solver = oms_solver_sc_cvode;
+  solverStats = false;
   startTime = 0.0;
   stopTime = 1.0;
+  stripRoot = false;
+  suppressPath = false;
   timeout = 0.0;
   tolerance = 1e-4;
-  solver = oms_solver_sc_cvode;
-  masterAlgorithm = oms_solver_wc_ma;
-  resultFile = "<default>";
+  wallTime = false;
 }
 
 oms::Flags& oms::Flags::GetInstance()
@@ -102,6 +113,8 @@ bool isOptionAndValue(const std::string& cmd, const std::string& name, std::stri
 
 oms_status_enu_t oms::Flags::SetCommandLineOption(const std::string& cmd)
 {
+  GetInstance().files.clear();
+
   // split command line arguments
   std::vector<std::string> args;
   size_t start=0;
@@ -143,7 +156,7 @@ oms_status_enu_t oms::Flags::SetCommandLineOption(const std::string& cmd)
 
     if (regex_match(value, oms_regex(regex_str)))
     {
-      oms_status_enu_t status = GetInstance().flags[l->second].fnc(value);
+      oms_status_enu_t status = GetInstance().flags[l->second].fcn(value);
       if (GetInstance().flags[l->second].interrupt || oms_status_ok != status)
         return status;
     }
@@ -151,6 +164,17 @@ oms_status_enu_t oms::Flags::SetCommandLineOption(const std::string& cmd)
       return logError("Invalid value: \"" + arg + "\"");
   }
 
+  // run Lua scripts, FMUs, SSP files
+  for (const auto& file : GetInstance().files)
+    if (oms_status_ok != oms_RunFile(file.c_str()))
+      return oms_status_error;
+
+  return oms_status_ok;
+}
+
+oms_status_enu_t oms::Flags::AddParametersToCSV(const std::string& value)
+{
+  GetInstance().addParametersToCSV = (value == "true");
   return oms_status_ok;
 }
 
@@ -160,9 +184,35 @@ oms_status_enu_t oms::Flags::ClearAllOptions(const std::string& value)
   return oms_status_ok;
 }
 
+oms_status_enu_t oms::Flags::DeleteTempFiles(const std::string& value)
+{
+  GetInstance().deleteTempFiles = (value == "true");
+  return oms_status_ok;
+}
+
+oms_status_enu_t oms::Flags::EmitEvents(const std::string& value)
+{
+  GetInstance().emitEvents = (value == "true");
+  return oms_status_ok;
+}
+
+oms_status_enu_t oms::Flags::ExportParametersInline(const std::string& value)
+{
+  GetInstance().exportParametersInline = (value == "true");
+  return oms_status_ok;
+}
+
 oms_status_enu_t oms::Flags::FetchAllVars(const std::string& value)
 {
-  oms::ComRef tail(value);
+  std::string cref = value;
+  bool enableOption = true;
+  if (value[0] == '-' || value[0] == '+')
+  {
+    enableOption = (value[0] == '+');
+    cref = cref.substr(1);
+  }
+
+  oms::ComRef tail(cref);
   oms::ComRef front = tail.pop_front();
 
   oms::Model* model = oms::Scope::GetInstance().getModel(front);
@@ -181,32 +231,46 @@ oms_status_enu_t oms::Flags::FetchAllVars(const std::string& value)
   if (component->getType() != oms_component_fmu)
     return oms_status_error;
 
-  component->fetchAllVars();
-  logDebug("--fetchAllVars is enabled for " + value);
+  component->fetchAllVars(enableOption);
+  if (enableOption)
+    logDebug("--fetchAllVars is enabled for " + cref);
+  else
+    logDebug("--fetchAllVars is disabled for " + cref);
   return oms_status_ok;
 }
 
 oms_status_enu_t oms::Flags::Filename(const std::string& value)
 {
-  oms_RunFile(value.c_str());
+  GetInstance().files.push_back(value);
   return oms_status_ok;
 }
 
 oms_status_enu_t oms::Flags::Help(const std::string& value)
 {
   std::stringstream ss;
+  ss << "Usage: OMSimulator [Options] [Lua script] [FMU] [SSP file]" << std::endl;
   ss << "Options:" << std::endl;
   for (unsigned int i=0; i<GetInstance().flags.size(); ++i)
   {
-    std::string label = "  " + GetInstance().flags[i].name;
     if (GetInstance().flags[i].name.empty())
-      label += "<filename>";
-    else if (!GetInstance().flags[i].regex.empty())
-      label += "=<arg>";
-    if (!GetInstance().flags[i].abbr.empty())
-      label += " [ " + GetInstance().flags[i].abbr + " ]";
+      continue;
 
-    ss << std::left << std::setw(28) << label << "  " << GetInstance().flags[i].desc << std::endl;
+    std::string label = "  " + GetInstance().flags[i].name;
+    if (!GetInstance().flags[i].regex.empty())
+    {
+      if (GetInstance().flags[i].regex == GetInstance().re_bool)
+        label += "=<bool>";
+      else if (GetInstance().flags[i].regex == GetInstance().re_double)
+        label += "=<double>";
+      else if (GetInstance().flags[i].regex == GetInstance().re_number)
+        label += "=<int>";
+      else
+        label += "=<arg>";
+    }
+    if (!GetInstance().flags[i].abbr.empty())
+      label += " [" + GetInstance().flags[i].abbr + "]";
+
+    ss << std::left << std::setw(32) << label << "  " << GetInstance().flags[i].desc << std::endl;
   }
 
   logInfo(ss.str());
@@ -219,6 +283,12 @@ oms_status_enu_t oms::Flags::IgnoreInitialUnknowns(const std::string& value)
   return oms_status_ok;
 }
 
+oms_status_enu_t oms::Flags::InputExtrapolation(const std::string& value)
+{
+  GetInstance().inputExtrapolation = (value == "true");
+  return oms_status_ok;
+}
+
 oms_status_enu_t oms::Flags::Intervals(const std::string& value)
 {
   GetInstance().intervals = atoi(value.c_str());
@@ -237,27 +307,57 @@ oms_status_enu_t oms::Flags::LogLevel(const std::string& value)
   return oms_status_ok;
 }
 
+oms_status_enu_t oms::Flags::MaxEventIteration(const std::string& value)
+{
+  GetInstance().maxEventIteration = atoi(value.c_str());
+  return oms_status_ok;
+}
+
+oms_status_enu_t oms::Flags::MaxLoopIteration(const std::string& value)
+{
+  GetInstance().maxLoopIteration = atoi(value.c_str());
+  return oms_status_ok;
+}
+
 oms_status_enu_t oms::Flags::Mode(const std::string& value)
 {
   GetInstance().defaultModeIsCS = (value == "cs");
   return oms_status_ok;
 }
 
+oms_status_enu_t oms::Flags::NumProcs(const std::string& value)
+{
+  GetInstance().numProcs = atoi(value.c_str());
+  return oms_status_ok;
+}
+
 oms_status_enu_t oms::Flags::ProgressBar(const std::string& value)
 {
   GetInstance().progressBar = (value == "true");
   return oms_status_ok;
 }
 
+oms_status_enu_t oms::Flags::RealTime(const std::string& value)
+{
+  GetInstance().realTime = (value == "true");
+  return oms_status_ok;
+}
+
 oms_status_enu_t oms::Flags::ResultFile(const std::string& value)
 {
-  GetInstance().resultFile = atof(value.c_str());
+  GetInstance().resultFile = value;
   return oms_status_ok;
 }
 
 oms_status_enu_t oms::Flags::SetInputDerivatives(const std::string& value)
 {
-  GetInstance().inputDerivatives = (value == "true");
+  logWarning("--setInputDerivatives is deprecated; use --inputExtrapolation instead");
+  return InputExtrapolation(value);
+}
+
+oms_status_enu_t oms::Flags::SkipCSVHeader(const std::string& value)
+{
+  GetInstance().skipCSVHeader = (value == "true");
   return oms_status_ok;
 }
 
@@ -268,7 +368,14 @@ oms_status_enu_t oms::Flags::Solver(const std::string& value)
   else if (value == "cvode")
     GetInstance().solver = oms_solver_sc_cvode;
   else
-    return oms_status_error;
+    return logError("Invalid solver method");
+
+  return oms_status_ok;
+}
+
+oms_status_enu_t oms::Flags::SolverStats(const std::string& value)
+{
+  GetInstance().solverStats = (value == "true");
   return oms_status_ok;
 }
 
@@ -284,6 +391,12 @@ oms_status_enu_t oms::Flags::StopTime(const std::string& value)
   return oms_status_ok;
 }
 
+oms_status_enu_t oms::Flags::StripRoot(const std::string& value)
+{
+  GetInstance().stripRoot = (value == "true");
+  return oms_status_ok;
+}
+
 oms_status_enu_t oms::Flags::SuppressPath(const std::string& value)
 {
   GetInstance().suppressPath = (value == "true");
