@@ -214,6 +214,28 @@ oms_status_enu_t oms_list(const char* cref_, char** contents)
   return model->list(tail, contents);
 }
 
+oms_status_enu_t oms_exportSnapshot(const char* cref_, char** contents)
+{
+  oms::ComRef tail(cref_);
+  oms::ComRef front = tail.pop_front();
+  oms::Model* model = oms::Scope::GetInstance().getModel(front);
+  if (!model)
+    return logError_ModelNotInScope(front);
+
+  return model->exportSnapshot(tail, contents);
+}
+
+oms_status_enu_t oms_exportSSVTemplate(const char* cref_, const char* filename)
+{
+  oms::ComRef tail(cref_);
+  oms::ComRef front = tail.pop_front();
+  oms::Model* model = oms::Scope::GetInstance().getModel(front);
+  if (!model)
+    return logError_ModelNotInScope(front);
+
+  return model->exportSSVTemplate(tail, std::string(filename));
+}
+
 oms_status_enu_t oms_listUnconnectedConnectors(const char* cref_, char** contents)
 {
   oms::ComRef tail(cref_);
@@ -240,6 +262,17 @@ oms_status_enu_t oms_loadSnapshot(const char* cref_, const char* snapshot)
   return model->loadSnapshot(snapshot);
 }
 
+oms_status_enu_t oms_importSnapshot(const char* cref_, const char* snapshot)
+{
+  oms::ComRef cref(cref_);
+
+  oms::Model* model = oms::Scope::GetInstance().getModel(cref);
+  if (!model)
+    return logError_ModelNotInScope(cref);
+
+  return model->importSnapshot(snapshot);
+}
+
 oms_status_enu_t oms_parseModelName(const char* contents, char** cref)
 {
   return logError_NotImplemented;
@@ -1175,7 +1208,7 @@ oms_status_enu_t oms_setTLMPositionAndOrientation(const char *cref, double x1, d
 #endif
 }
 
-oms_status_enu_t oms_exportDependencyGraphs(const char* cref, const char* initialization, const char* simulation)
+oms_status_enu_t oms_exportDependencyGraphs(const char* cref, const char* initialization, const char* event, const char* simulation)
 {
   oms::ComRef tail(cref);
   oms::ComRef front = tail.pop_front();
@@ -1189,7 +1222,7 @@ oms_status_enu_t oms_exportDependencyGraphs(const char* cref, const char* initia
   if (!system)
     return logError_SystemNotInModel(model->getCref(), tail);
 
-  return system->exportDependencyGraphs(initialization, simulation);
+  return system->exportDependencyGraphs(initialization, event, simulation);
 }
 
 oms_status_enu_t oms_getReal(const char* cref, double* value)
@@ -1209,6 +1242,38 @@ oms_status_enu_t oms_getReal(const char* cref, double* value)
   return system->getReal(tail, *value);
 }
 
+oms_status_enu_t oms_getResultFile(const char* cref_, char** filename, int* bufferSize)
+{
+  oms::ComRef cref(cref_);
+
+  if (cref.isValidIdent())
+  {
+    oms::Model* model = oms::Scope::GetInstance().getModel(cref);
+    if (!model)
+      return logError_ModelNotInScope(cref);
+
+    return model->getResultFile(filename, bufferSize);
+  }
+  else
+    return logError_OnlyForModel;
+}
+
+oms_status_enu_t oms_getSignalFilter(const char* cref_, char** regex)
+{
+  oms::ComRef cref(cref_);
+
+  if (cref.isValidIdent())
+  {
+    oms::Model* model = oms::Scope::GetInstance().getModel(cref);
+    if (!model)
+      return logError_ModelNotInScope(cref);
+
+    return model->getSignalFilter(regex);
+  }
+  else
+    return logError_OnlyForModel;
+}
+
 oms_status_enu_t oms_getSolver(const char* cref, oms_solver_enu_t* solver)
 {
   oms::ComRef tail(cref);
@@ -1353,17 +1418,20 @@ oms_status_enu_t oms_setSignalFilter(const char* cref, const char* regex)
 {
   oms_status_enu_t status;
 
-  status = oms_removeSignalsFromResults(cref, ".*");
-  if (oms_status_ok != status) return status;
+  oms::ComRef tail(cref);
+  oms::ComRef front = tail.pop_front();
 
-  status = oms_addSignalsToResults(cref, regex);
-  if (oms_status_ok != status) return status;
+  oms::Model* model = oms::Scope::GetInstance().getModel(front);
+  if (!model)
+    return logError_ModelNotInScope(front);
 
-  return oms_status_ok;
+  return model->setSignalFilter(regex);
 }
 
 oms_status_enu_t oms_addSignalsToResults(const char* cref, const char* regex)
 {
+  logWarning("[oms_addSignalsToResults] will not update the signalFilters in ssp, use [oms_setSignalFilter]");
+
   oms::ComRef tail(cref);
   oms::ComRef front = tail.pop_front();
 
@@ -1376,6 +1444,8 @@ oms_status_enu_t oms_addSignalsToResults(const char* cref, const char* regex)
 
 oms_status_enu_t oms_removeSignalsFromResults(const char* cref, const char* regex)
 {
+  logWarning("[oms_removeSignalsFromResults] will not update the signalFilters in ssp, use [oms_setSignalFilter]");
+
   oms::ComRef tail(cref);
   oms::ComRef front = tail.pop_front();
 
@@ -1598,6 +1668,55 @@ oms_status_enu_t oms_extractFMIKind(const char* filename, oms_fmi_kind_enu_t* ki
   return oms_status_ok;
 }
 
+oms_status_enu_t oms_fetchExternalModelInterfaces(const char* cref, char*** names, char*** domains, int** dimensions)
+{
+#if !defined(NO_TLM)
+  oms::ComRef tail(cref);
+  oms::ComRef front = tail.pop_front();
+
+  oms::Model* model = oms::Scope::GetInstance().getModel(front);
+  if (!model)
+    return logError_ModelNotInScope(front);
+
+  front = tail.pop_front();
+  oms::System* system = model->getSystem(front);
+  if (!system)
+    return logError_SystemNotInModel(model->getCref(), front);
+
+  if (system->getType() != oms_system_tlm)
+    return logError_OnlyForSystemTLM;
+
+  oms::SystemTLM* tlmsystem = reinterpret_cast<oms::SystemTLM*>(system);
+  std::vector<std::string> namesVec,domainsVec;
+  std::vector<int> dimensionsVec;
+
+  oms_status_enu_t status = tlmsystem->fetchInterfaces(tail,namesVec,dimensionsVec,domainsVec);
+
+  (*names) = new char*[namesVec.size()+1];
+  for(int i=0; i<namesVec.size(); ++i) {
+    (*names)[i] = new char[namesVec[i].size()+1];
+    strcpy((*names)[i], namesVec[i].c_str());
+  }
+  (*names)[namesVec.size()] = nullptr;
+
+  (*domains) = new char*[domainsVec.size()+1];
+  for(int i=0; i<domainsVec.size(); ++i) {
+    (*domains)[i] = new char[domainsVec[i].size()+1];
+    strcpy((*domains)[i], domainsVec[i].c_str());
+  }
+  (*domains)[domainsVec.size()] = nullptr;
+
+  (*dimensions) = new int[dimensionsVec.size()+1];
+  for(int i=0; i<dimensionsVec.size(); ++i) {
+    (*dimensions)[i] = dimensionsVec[i];
+  }
+
+  return status;
+#else
+  return LOG_NO_TLM();
+#endif
+}
+
 oms_status_enu_t oms_setSolver(const char* cref, oms_solver_enu_t solver)
 {
   oms::ComRef tail(cref);
